==> Gbook-0.8.tar.gz: Gbook/lang/ext/de_DE.php <==
<?php
$lang['friendlyname'] = 'G&auml;steb&uuml;cher';
$lang['moddescription'] = 'Erstellen und Verwalten von G&auml;steb&uuml;chern, um einige Nachrichten von Ihrer Website-Besuchern zu erhalten';
$lang['description'] = 'Erhalte Nachrichten von Website-Besuchern';
$lang['postinstall'] = 'Das Gbook Modul wurde erfolgreich installiert. Pr&uuml;fen Sie Inhalts-Bereich f&uuml;r &#039;%s&#039;.';
$lang['areyousure'] = 'Sind Sie sicher, dass Sie l&ouml;schen m&ouml;chten?';
$lang['areyousuremulti'] = 'Sind Sie sicher das Sie diese Massenaktion ausf&uuml;hren wollen?';
$lang['gbooks'] = 'G&auml;steb&uuml;cher';
$lang['addgbook'] = 'G&auml;stebuch hinzuf&uuml;gen';
$lang['gbookadded'] = 'Das G&auml;stebuch wurde hinzugef&uuml;gt';
$lang['editgbook'] = 'G&auml;stebuch bearbeiten';
$lang['gbookupdated'] = 'Das G&auml;stebuch wurde aktualisiert';
$lang['gbookdeleted'] = 'Das G&auml;stebuch wurde gel&ouml;scht';
$lang['entries_page'] = 'Anzahl der Eintr&auml;ge pro Seite';
$lang['prevent_post_twice'] = 'Verhindere aufeinanderfolgenden Nachrichten von demselben Benutzer (basiert auf IP-Adresse)';
$lang['allow_smilies'] = 'Erlaube Smileys';
$lang['allow_notifications'] = 'Benachrichtigungsoption aktivieren';
$lang['notification_subject'] = 'Betreff der Benachrichtigung';
$lang['notification_message'] = 'Inhalt der Benachrichtigung';
$lang['submission_response'] = 'Antwort auf Formular&uuml;bermittlung';
$lang['submission_response_spam'] = 'Reaktion auf Spam-Verdacht Formular&uuml;bermittlung';
$lang['admin_notification_subject'] = 'Betreff der Admin Benachrichtigung';
$lang['admin_notification_message'] = 'Inhalt der Admin Benachrichtigung';
$lang['required_fields'] = 'Pflichtangaben auf Frontend';
$lang['import_csv'] = 'Importier Eintr&auml;ge von CSV-Datei';
$lang['csv_format'] = 'CSV Format: &quot;author&quot;[string];&quot;email&quot;[string];&quot;title&quot;[string];&quot;message&quot;[string];&quot;ip&quot;[string];&quot;create_date&quot;[date/time:yyyy-mm-dd hh:mm:ss]';
$lang['smileys'] = 'Smileys ';
$lang['smiley'] = 'Smiley ';
$lang['addsmiley'] = 'Smiley hinzuf&uuml;gen';
$lang['id'] = 'ID ';
$lang['spamrate'] = 'Spam Bewertung';
$lang['created'] = 'Eintragsdatum';
$lang['modified'] = 'Ge&auml;ndert';
$lang['itemadded'] = 'Der Eintrag wurde hinzugef&uuml;gt';
$lang['edititem'] = 'Eintrag bearbeiten';
$lang['itemupdated'] = 'Der Eintrag wurde ge&auml;ndert';
$lang['itemdeleted'] = 'Der Eintrag wurde gel&ouml;scht';
$lang['saveasham'] = 'Eintrag als &quot;kein Spam&quot; markieren';
$lang['saveasspam'] = 'Eintrag als &quot;Spam&quot; markieren';
$lang['deletefromham'] = 'Unmarkier Eintrag von &quot;kein Spam&quot;';
$lang['deletefromspam'] = 'Unmarkier Eintrag von &quot;Spam&quot;';
$lang['summary_tpl'] = 'Listenansicht';
$lang['detail_tpl'] = 'Detailansichts';
$lang['form_tpl'] = 'Formular-Anzeige';
$lang['default_summary_template'] = 'Standard Listenansicht';
$lang['default_detail_template'] = 'Standard Detailansichts';
$lang['resetdefault'] = 'Template Laden/Zur&uuml;cksetzen';
$lang['resetwarning'] = 'Sind Sie sicher das Sie dass Template zur&uuml;cksetzen m&ouml;chten?';
$lang['send_notifications_to'] = 'E-Mail-Adresse um Benachrichtigungen &uuml;ber neue Eintr&auml;ge zu erhalten';
$lang['max_spamrate_active'] = 'Maximaler spamrating um ein Eintrag automatisch nach &Uuml;bermittlung zu aktivieren';
$lang['max_spamrate_active_help'] = 'zwischen 0 und 1, Voreingestellt ist 0.6. Kleinerer Wert bedeutet strengere Einstellung.';
$lang['max_spamrate_notify'] = 'Maximaler spamrating um Administrator zu Benachrichtigen';
$lang['max_spamrate_notify_help'] = 'zwischen 0 und 1, Voreingestellt ist 0.9. H&ouml;herer Wert erh&ouml;ht die Chance auf Meldungen von Spam-Eintr&auml;gen.';
$lang['max_spamrate_save'] = 'Maximaler spamrating zum Speichern eines neuen Eintrags';
$lang['max_spamrate_save_help'] = 'zwischen 0 und 1, Voreingestellt ist 0.9. Kleinerer Wert erh&ouml;ht Verlust-Chancen legitimer eintr&auml;ge.';
$lang['optionsupdated'] = 'Die Einstellungen wurden aktualisiert.';
$lang['entries'] = 'Eintr&auml;ge';
$lang['name'] = 'Name ';
$lang['email'] = 'E-Mail';
$lang['title'] = 'Titel';
$lang['message'] = 'Nachricht';
$lang['notify'] = 'Benachrichtigen Sie mich bei neuen Nachrichten';
$lang['fe_submit'] = 'Absenden';
$lang['validation_errors'] = 'Bitte geben Sie einen g&uuml;ltigen Eintrag f&uuml;r den markierten Felder und sende nochmal.';
$lang['double_post'] = '<p>Vielen Dank. Ihre Nachricht wurde bereits eingetragen.</p>';
$lang['not_allowed_to_post_twice'] = '<p>Entschuldigung. Durch Spam-Schutz ist es nicht m&ouml;glich, zwei aufeinanderfolgende Nachrichten einzutragen.</p>
<p>Bitte versuchen Sie es sp&auml;ter noch einmal oder senden Sie uns eine E-Mail, damit wir Ihre Nachricht an unsere Website hinzuf&uuml;gen k&ouml;nnen.</p>';
$lang['submission_response_cnt'] = '<p>Vielen Dank. Ihre Nachricht wurde eingetragen.</p>';
$lang['submission_response_spam_cnt'] = '<p>Vielen Dank f&uuml;r Ihre Eintrag.</p>
<p>Ihr Eintrag wird nach &Uuml;berpr&uuml;fung durch den Administrator im G&auml;stebuch angezeigt.</p>
';
$lang['admin_notification_subject_cnt'] = 'Neue G&auml;stebucheintrag';
$lang['admin_notification_message_cnt'] = 'Sie haben eine neue Nachricht erhalten in Ihrem {sitename} G&auml;stebuch.

&Uuml;berpr&uuml;fen Sie es auf: {root_url}';
$lang['help_action'] = 'Possible values: <ul><li>&#039;default&#039; - for displaying the guestbook entries</li><li>&#039;form&#039; - for displaying a form</li><li>&#039;detail&#039; - for displaying a single entry, e.g. as search result</li><ul> ';
$lang['help_alias'] = 'Use another guestbook than the default one. Check the Guestbooks-tab, column &#039;Tags&#039;, to see which aliases can be used.';
$lang['help_entryid'] = 'Use this parameter along with <code>action=&#039;detail&#039;</code> if you want to display only one guestbook entry. To get the latest entry, use <code>entryid=-1</code> ';
$lang['help_template'] = 'Use another template than the default one. Note that templates must be of the proper type, in accordance with the action parameter. ';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>The Gbook module provides your site visitors a convenient way to give some feedback on your site. Messages can include smileys and your guestbook is effectively protected from spam without the necessity of using an annoying captcha.</p>
<h3>How Do I Use It</h3>
<p>To show the guestbook entries, just insert the module with the<code> {Gbook} </code>tag into the content section of a page.<br />
You can display a form with the<code> {Gbook action=&#039;form&#039;} </code>tag.</p>
<p>To get a quick start, a sample stylesheet has been installed which corresponds with the default module templates. Attach the stylesheet &#039;Gbook module&#039; to your page template(s) to give your guestbook a first good look.</p>

<h3>Edit Guestbook Entries</h3>
<p>Users with the &#039;Gbook: Use&#039; permission can edit guestbook entries in the backend.</p>

<h3>Spam Protection</h3>
<p>Gbook proudly uses the &quot;b8&quot; statistical (Bayesian) spam filter version 0.6, written by Tobias Leupold. This built-in spam protection system will only function after you have learned it how to interpret the messages by marking the first few entries as either &quot;Spam&quot; or &quot;Ham&quot;. If the system has learned enough good as well as enough bad words, it will give spam messages a rating somewhere near 1, and ham messages will be rated somewhere near 0. Messages with a rating of 0.50 could not be rated because of too few matching words.<br />Note that it won&#039;t be of use to manually mark entries as spam or ham, which are already rated as such.</p>
<p>If you want to know more of this excellent spam protection system, you can visit <a href="http://nasauber.de/opensource/b8/">nasauber.de</a>.</p>

<h3>Customisation</h3>
<p>The Guestbooks-tab in the admin section allows you to create more separate guestbooks. Each can have its own settings.<br />
Users must belong to a group with the &#039;Gbook: Modify&#039; permission to be able to create new guestbooks and to change settings.</p>

<h3>Import Guestbook Entries</h3>
<p>If you are migrating your site from another CMS or from another guestbook system, you probably might want to create a csv file containing all entries you have received in the past.</p>
<p>This csv file can easily be imported to Gbook, when it is formatted with fields in a specific order, separated by semicolons and enclosed by double quotes, like this:<br />
<code>&quot;author&quot;;&quot;email&quot;;&quot;title&quot;;&quot;message&quot;;&quot;ip&quot;;&quot;create_date&quot;</code></p>
<p>All fields are of type [string]. The field <em>create_date</em> needs to be formatted as &quot;yyyy-mm-dd hh:mm:ss&quot;</p>

<h3>Edit Gbook templates</h3>
<p>In order to edit templates, the user must belong to a group with the &#039;Modify Templates&#039; permission.</p>

<h3>Global Gbook Options</h3>
<p>To edit the global Gbook options, the user must belong to a group with the &#039;Modify Site Preferences&#039; permission.</p>

<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>FAQs, extended module help and Troubleshooting can be found in the <a href="http://wiki.cmsms.nl/index.php/Gbook">Gbook Wiki Documentation</a>.</li>
<li>For the latest version of this module or to file a Feature Request or Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/gbook/">Gbook Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>. You are warmly invited to open a new topic if you didn&#039;t find an answer to your question.</li>
<li>Lastly, you may have some success emailing the author directly.</li>
</ul>

<h3>Feedback</h3>
<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>
';
$lang['utmz'] = '156861353.1355667847.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
$lang['utma'] = '156861353.594691262.1355667847.1355667847.1355667847.1';
$lang['qca'] = 'P0-802263609-1268423862699';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>

==> Gbook-1.1.tar.gz: Gbook/lang/ext/de_DE.php <==
<?php
$lang['friendlyname'] = 'G&auml;steb&uuml;cher';
$lang['moddescription'] = 'Erstellen und Verwalten von G&auml;steb&uuml;chern, um einige Nachrichten von Ihrer Website-Besuchern zu erhalten';
$lang['description'] = 'Erhalte Nachrichten von Website-Besuchern';
$lang['postinstall'] = 'Das Gbook Modul wurde erfolgreich installiert. Pr&uuml;fen Sie Inhalts-Bereich f&uuml;r &#039;%s&#039;.';
$lang['areyousure'] = 'Sind Sie sicher, dass Sie l&ouml;schen m&ouml;chten?';
$lang['areyousuremulti'] = 'Sind Sie sicher das Sie diese Massenaktion ausf&uuml;hren wollen?';
$lang['gbooks'] = 'G&auml;steb&uuml;cher';
$lang['addgbook'] = 'G&auml;stebuch hinzuf&uuml;gen';
$lang['gbookadded'] = 'Das G&auml;stebuch wurde hinzugef&uuml;gt';
$lang['editgbook'] = 'G&auml;stebuch bearbeiten';
$lang['gbookupdated'] = 'Das G&auml;stebuch wurde aktualisiert';
$lang['gbookdeleted'] = 'Das G&auml;stebuch wurde gel&ouml;scht';
$lang['entries_page'] = 'Anzahl der Eintr&auml;ge pro Seite';
$lang['prevent_post_twice'] = 'Verhindere aufeinanderfolgenden Nachrichten von demselben Benutzer (basiert auf IP-Adresse)';
$lang['allow_smilies'] = 'Erlaube Smileys';
$lang['allow_notifications'] = 'Benachrichtigungsoption aktivieren';
$lang['notification_subject'] = 'Betreff der Benachrichtigung';
$lang['notification_message'] = 'Inhalt der Benachrichtigung';
$lang['submission_response'] = 'Antwort auf Formular&uuml;bermittlung';
$lang['submission_response_spam'] = 'Reaktion auf Spam-Verdacht Formular&uuml;bermittlung';
$lang['admin_notification_subject'] = 'Betreff der Admin Benachrichtigung';
$lang['admin_notification_message'] = 'Inhalt der Admin Benachrichtigung';
$lang['required_fields'] = 'Pflichtangaben auf Frontend';
$lang['import_csv'] = 'Importier Eintr&auml;ge von CSV-Datei';
$lang['csv_format'] = 'CSV Format: &quot;author&quot;[string];&quot;email&quot;[string];&quot;title&quot;[string];&quot;message&quot;[string];&quot;ip&quot;[string];&quot;create_date&quot;[date/time:yyyy-mm-dd hh:mm:ss]';
$lang['smileys'] = 'Smileys ';
$lang['smiley'] = 'Smiley ';
$lang['addsmiley'] = 'Smiley hinzuf&uuml;gen';
$lang['id'] = 'ID ';
$lang['spamrate'] = 'Spam Bewertung';
$lang['created'] = 'Eintragsdatum';
$lang['modified'] = 'Ge&auml;ndert';
$lang['itemadded'] = 'Der Eintrag wurde hinzugef&uuml;gt';
$lang['edititem'] = 'Eintrag bearbeiten';
$lang['itemupdated'] = 'Der Eintrag wurde ge&auml;ndert';
$lang['itemdeleted'] = 'Der Eintrag wurde gel&ouml;scht';
$lang['saveasham'] = 'Eintrag als &quot;kein Spam&quot; markieren';
$lang['saveasspam'] = 'Eintrag als &quot;Spam&quot; markieren';
$lang['deletefromham'] = 'Unmarkier Eintrag von &quot;kein Spam&quot;';
$lang['deletefromspam'] = 'Unmarkier Eintrag von &quot;Spam&quot;';
$lang['summary_tpl'] = 'Listenansicht';
$lang['detail_tpl'] = 'Detailansichts';
$lang['form_tpl'] = 'Formular-Anzeige';
$lang['default_summary_template'] = 'Standard Listenansicht';
$lang['default_detail_template'] = 'Standard Detailansichts';
$lang['resetdefault'] = 'Template Laden/Zur&uuml;cksetzen';
$lang['resetwarning'] = 'Sind Sie sicher das Sie dass Template zur&uuml;cksetzen m&ouml;chten?';
$lang['send_notifications_to'] = 'E-Mail-Adresse um Benachrichtigungen &uuml;ber neue Eintr&auml;ge zu erhalten';
$lang['max_spamrate_active'] = 'Maximaler spamrating um ein Eintrag automatisch nach &Uuml;bermittlung zu aktivieren';
$lang['max_spamrate_active_help'] = 'zwischen 0 und 1, Voreingestellt ist 0.6. Kleinerer Wert bedeutet strengere Einstellung.';
$lang['max_spamrate_notify'] = 'Maximaler spamrating um Administrator zu Benachrichtigen';
$lang['max_spamrate_notify_help'] = 'zwischen 0 und 1, Voreingestellt ist 0.9. H&ouml;herer Wert erh&ouml;ht die Chance auf Meldungen von Spam-Eintr&auml;gen.';
$lang['max_spamrate_save'] = 'Maximaler spamrating zum Speichern eines neuen Eintrags';
$lang['max_spamrate_save_help'] = 'zwischen 0 und 1, Voreingestellt ist 0.9. Kleinerer Wert erh&ouml;ht Verlust-Chancen legitimer eintr&auml;ge.';
$lang['badwords'] = 'Maskiere ungezogene W&ouml;rter (Komma getrennt)';
$lang['optionsupdated'] = 'Die Einstellungen wurden aktualisiert.';
$lang['entries'] = 'Eintr&auml;ge';
$lang['name'] = 'Name ';
$lang['email'] = 'E-Mail';
$lang['title'] = 'Titel';
$lang['message'] = 'Nachricht';
$lang['notify'] = 'Benachrichtigen Sie mich bei neuen Nachrichten';
$lang['fe_submit'] = 'Absenden';
$lang['validation_errors'] = 'Bitte geben Sie einen g&uuml;ltigen Eintrag f&uuml;r den markierten Felder und sende nochmal.';
$lang['double_post'] = '<p>Vielen Dank. Ihre Nachricht wurde bereits eingetragen.</p>';
$lang['not_allowed_to_post_twice'] = '<p>Entschuldigung. Durch Spam-Schutz ist es nicht m&ouml;glich, zwei aufeinanderfolgende Nachrichten einzutragen.</p>
<p>Bitte versuchen Sie es sp&auml;ter noch einmal oder senden Sie uns eine E-Mail, damit wir Ihre Nachricht an unsere Website hinzuf&uuml;gen k&ouml;nnen.</p>';
$lang['submission_response_cnt'] = '<p>Vielen Dank. Ihre Nachricht wurde eingetragen.</p>';
$lang['submission_response_spam_cnt'] = '<p>Vielen Dank f&uuml;r Ihre Eintrag.</p>
<p>Ihr Eintrag wird nach &Uuml;berpr&uuml;fung durch den Administrator im G&auml;stebuch angezeigt.</p>
';
$lang['admin_notification_subject_cnt'] = 'Neue G&auml;stebucheintrag';
$lang['admin_notification_message_cnt'] = 'Sie haben eine neue Nachricht erhalten in Ihrem {sitename} G&auml;stebuch.

&Uuml;berpr&uuml;fen Sie es auf: {root_url}';
$lang['help_action'] = 'Possible values: <ul><li>&#039;default&#039; - for displaying the guestbook entries</li><li>&#039;form&#039; - for displaying a form</li><li>&#039;detail&#039; - for displaying a single entry, e.g. as search result</li></ul> ';
$lang['help_alias'] = 'Use another guestbook than the default one. Check the Guestbooks-tab, column &#039;Tags&#039;, to see which aliases can be used.';
$lang['help_entryid'] = 'Use this parameter along with <code>action=&#039;detail&#039;</code> if you want to display only one guestbook entry. To get the latest entry, use <code>entryid=-1</code> ';
$lang['help_template'] = 'Use another template than the default one. Note that templates must be of the proper type, in accordance with the action parameter. ';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>The Gbook module provides your site visitors a convenient way to give some feedback on your site. Messages can include smileys and your guestbook is effectively protected from spam without the necessity of using an annoying captcha.</p>
<h3>How Do I Use It</h3>
<p>To show the guestbook entries, just insert the module with the<code> {Gbook} </code>tag into the content section of a page.<br />
You can display a form with the<code> {Gbook action=&#039;form&#039;} </code>tag.</p>
<p>To get a quick start, a sample stylesheet has been installed which corresponds with the default module templates. Attach the stylesheet &#039;Gbook module&#039; to your page template(s) to give your guestbook a first good look.</p>

<h3>Edit Guestbook Entries</h3>
<p>Users with the &#039;Gbook: Use&#039; permission can edit guestbook entries in the backend.</p>

<h3>Spam Protection</h3>
<p>Gbook proudly uses the &quot;b8&quot; statistical (Bayesian) spam filter version 0.6, written by Tobias Leupold. This built-in spam protection system will only function after you have learned it how to interpret the messages by marking the first few entries as either &quot;Spam&quot; or &quot;Ham&quot;. If the system has learned enough good as well as enough bad words, it will give spam messages a rating somewhere near 1, and ham messages will be rated somewhere near 0. Messages with a rating of 0.50 could not be rated because of too few matching words.<br />Note that it won&#039;t be of use to manually mark entries as spam or ham, which are already rated as such.</p>
<p>If you want to know more of this excellent spam protection system, you can visit <a href="http://nasauber.de/opensource/b8/">nasauber.de</a>.</p>

<h3>Customisation</h3>
<p>The Guestbooks-tab in the admin section allows you to create more separate guestbooks. Each can have its own settings.<br />
Users must belong to a group with the &#039;Gbook: Modify&#039; permission to be able to create new guestbooks and to change settings.</p>

<h3>Import Guestbook Entries</h3>
<p>If you are migrating your site from another CMS or from another guestbook system, you probably might want to create a csv file containing all entries you have received in the past.</p>
<p>This csv file can easily be imported to Gbook, when it is formatted with fields in a specific order, separated by semicolons and enclosed by double quotes, like this:<br />
<code>&quot;author&quot;;&quot;email&quot;;&quot;title&quot;;&quot;message&quot;;&quot;ip&quot;;&quot;create_date&quot;</code></p>
<p>All fields are of type [string]. The field <em>create_date</em> needs to be formatted as &quot;yyyy-mm-dd hh:mm:ss&quot;</p>

<h3>Edit Gbook templates</h3>
<p>In order to edit templates, the user must belong to a group with the &#039;Modify Templates&#039; permission.</p>

<h3>Global Gbook Options</h3>
<p>To edit the global Gbook options, the user must belong to a group with the &#039;Modify Site Preferences&#039; permission.</p>

<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>FAQs, extended module help and Troubleshooting can be found in the <a href="http://wiki.cmsms.nl/index.php/Gbook">Gbook Wiki Documentation</a>.</li>
<li>For the latest version of this module or to file a Feature Request or Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/gbook/">Gbook Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>. You are warmly invited to open a new topic if you didn&#039;t find an answer to your question.</li>
<li>Lastly, you may have some success emailing the author directly.</li>
</ul>

<h3>Feedback</h3>
<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/viewtopic.php?f=7&amp;t=64460">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>
';
$lang['utmz'] = '156861353.1355837206.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utma'] = '156861353.238888043.1355837206.1355837206.1355837206.1';
$lang['qca'] = 'P0-802263609-1268423862699';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
